@@ -1,10 +1,7 @@
-import httplib2
 import json
 import os
 import re
-import sys
-import time
-from urlparse import urlparse
+from six.moves.urllib.parse import urlparse
 import xml.dom.minidom
 
 from proboscis.asserts import *
@@ -46,11 +43,11 @@ class ConfigFile(object):
             auth_id = self.tenant
             tenant_id = self.tenant
 
-        print "id = %s" % auth_id
+        print("id = %s" % auth_id)
         self.headers = {
             'X-Auth-Token': str(auth_id)
         }
-        print "tenantID = %s" % tenant_id
+        print("tenantID = %s" % tenant_id)
         self.tenantID = tenant_id
         self.dbaas_url = "%s/v1.0/%s" % (self.api_url, self.tenantID)
 
