@@ -15,6 +15,7 @@
 """Model classes that form the core of snapshots functionality."""
 
 from oslo_log import log as logging
+from requests.exceptions import ConnectionError
 from sqlalchemy import desc
 from swiftclient.client import ClientException
 
@@ -29,7 +30,6 @@ from trove.db.models import DatabaseModelBase
 from trove.quota.quota import run_with_quotas
 from trove.taskmanager import api
 
-
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
@@ -291,6 +291,8 @@ class Backup(object):
             raise exception.SwiftAuthError(tenant_id=context.tenant)
         except exception.NoServiceEndpoint:
             raise exception.SwiftNotFound(tenant_id=context.tenant)
+        except ConnectionError:
+            raise exception.SwiftConnectionError()
 
 
 def persisted_models():
@@ -299,12 +301,12 @@ def persisted_models():
 
 class DBBackup(DatabaseModelBase):
     """A table for Backup records."""
-    _data_fields = ['id', 'name', 'description', 'location', 'backup_type',
+    _data_fields = ['name', 'description', 'location', 'backup_type',
                     'size', 'tenant_id', 'state', 'instance_id',
                     'checksum', 'backup_timestamp', 'deleted', 'created',
                     'updated', 'deleted_at', 'parent_id',
                     'datastore_version_id']
-    preserve_on_delete = True
+    _table_name = 'backups'
 
     @property
     def is_running(self):
