@@ -50,7 +50,7 @@ configuration_positive_integer = {
     "type": "string",
     "maxLength": 40,
     "minLength": 1,
-    "pattern": "^[0-9]+$"
+    "pattern": "^0*[1-9]+[0-9]*$"
 }
 
 configuration_non_empty_string = {
@@ -72,7 +72,16 @@ volume_size = {
     "oneOf": [
         {
             "type": "integer",
-            "minimum": 0
+            "minimum": 1
+        },
+        configuration_positive_integer]
+}
+
+number_of_nodes = {
+    "oneOf": [
+        {
+            "type": "integer",
+            "minimum": 1
         },
         configuration_positive_integer]
 }
@@ -254,7 +263,19 @@ cluster = {
                             }
                         }
                     },
-                    "locality": non_empty_string
+                    "locality": non_empty_string,
+                    "extended_properties": {
+                        "type": "object",
+                        "additionalProperties": True,
+                        "properties": {
+                            "num_configsvr": number_of_nodes,
+                            "num_mongos": number_of_nodes,
+                            "configsvr_volume_size": volume_size,
+                            "configsvr_volume_type": non_empty_string,
+                            "mongos_volume_size": volume_size,
+                            "mongos_volume_type": non_empty_string
+                        }
+                    }
                 }
             }
         }
