@@ -168,9 +168,9 @@ common_opts = [
     cfg.IntOpt('modules_page_size', default=20,
                help='Page size for listing modules.'),
     cfg.IntOpt('agent_call_low_timeout', default=15,
-               help="Maximum time (in seconds) to wait for Guest Agent 'quick'"
-                    "requests (such as retrieving a list of users or "
-                    "databases)."),
+               help="Maximum time (in seconds) to wait for Guest Agent "
+                    "'quick' requests (such as retrieving a list of "
+                    "users or databases)."),
     cfg.IntOpt('agent_call_high_timeout', default=60 * 10,
                help="Maximum time (in seconds) to wait for Guest Agent 'slow' "
                     "requests (such as restarting the database)."),
@@ -1080,6 +1080,10 @@ mongodb_opts = [
     cfg.IntOpt('num_query_routers_per_cluster', default=1,
                help='The number of query routers (mongos) to create '
                     'per cluster.'),
+    cfg.IntOpt('query_routers_volume_size', default=10,
+               help='Default volume_size (in GB) for query routers (mongos).'),
+    cfg.IntOpt('config_servers_volume_size', default=10,
+               help='Default volume_size (in GB) for config_servers.'),
     cfg.BoolOpt('cluster_support', default=True,
                 help='Enable clusters to be created and managed.'),
     cfg.BoolOpt('cluster_secure', default=True,
