@@ -80,7 +80,7 @@ def launch(app_name, port, paste_config_file, data={},
     app = pastedeploy.paste_deploy_app(paste_config_file, app_name, data)
     server = base_wsgi.Service(app, port, host=host,
                                backlog=backlog, threads=threads)
-    return service.launch(CONF, server, workers)
+    return service.launch(CONF, server, workers, restart_method='mutate')
 
 
 # Note: taken from Nova
@@ -197,16 +197,16 @@ class Request(base_wsgi.Request):
     @utils.cached_property
     def accept_version(self):
         accept_header = self.headers.get('ACCEPT', "")
-        accept_version_re = re.compile(".*?application/vnd.openstack.trove"
-                                       "(\+.+?)?;"
-                                       "version=(?P<version_no>\d+\.?\d*)")
+        accept_version_re = re.compile(r".*?application/vnd.openstack.trove"
+                                       r"(\+.+?)?;"
+                                       r"version=(?P<version_no>\d+\.?\d*)")
 
         match = accept_version_re.search(accept_header)
         return match.group("version_no") if match else None
 
     @utils.cached_property
     def url_version(self):
-        versioned_url_re = re.compile("/v(?P<version_no>\d+\.?\d*)")
+        versioned_url_re = re.compile(r"/v(?P<version_no>\d+\.?\d*)")
         match = versioned_url_re.search(self.path)
         return match.group("version_no") if match else None
 
@@ -347,6 +347,7 @@ class Controller(object):
             exception.DatastoreNotFound,
             exception.SwiftNotFound,
             exception.ModuleTypeNotFound,
+            exception.RootHistoryNotFound,
         ],
         webob.exc.HTTPConflict: [
             exception.BackupNotCompleteError,
@@ -360,6 +361,7 @@ class Controller(object):
         webob.exc.HTTPServerError: [
             exception.VolumeCreationFailure,
             exception.UpdateGuestError,
+            exception.SwiftConnectionError,
         ],
         webob.exc.HTTPNotImplemented: [
             exception.VolumeNotSupported,
@@ -507,7 +509,7 @@ class Fault(webob.exc.HTTPException):
 
         content_type = req.best_match_content_type()
         serializer = {
-            'application/json': base_wsgi.JSONDictSerializer(),
+            'application/json': JSONDictSerializer(),
         }[content_type]
 
         self.wrapped_exc.body = serializer.serialize(fault_data, content_type)
@@ -655,10 +657,3 @@ class DictSerializer(ActionDispatcher):
 
     def default(self, data):
         return ""
-
-
-class JSONDictSerializer(DictSerializer):
-    """Default JSON request body serialization."""
-
-    def default(self, data):
-        return jsonutils.dump_as_bytes(data)
