@@ -445,7 +445,7 @@ class PgSqlApp(object):
         """
         r = operating_system.read_file(self.pgsql_recovery_config,
                                        as_root=True)
-        regexp = re.compile("host=(\d+.\d+.\d+.\d+) ")
+        regexp = re.compile(r"host=(\d+.\d+.\d+.\d+) ")
         m = regexp.search(r)
         return m.group(1)
 
@@ -838,10 +838,10 @@ class PgSqlAdmin(object):
         :type user:               PostgreSQLUser
         """
         # Postgresql requires that you revoke grants before dropping the user
-        dbs = self.list_access(context, user.name, None)
-        for d in dbs:
-            db = models.PostgreSQLSchema.deserialize(d)
-            self.revoke_access(context, user.name, None, db.name)
+        databases = list(self.list_access(context, user.name, None))
+        for db in databases:
+            db_schema = models.PostgreSQLSchema.deserialize(db)
+            self.revoke_access(context, user.name, None, db_schema.name)
 
         LOG.info(
             "{guest_id}: Dropping user {name}.".format(
