@@ -75,7 +75,7 @@ MYSQL_CONFIG = {operating_system.REDHAT: "/etc/my.cnf",
 MYSQL_BIN_CANDIDATES = ["/usr/sbin/mysqld", "/usr/libexec/mysqld"]
 MYSQL_OWNER = 'mysql'
 CNF_EXT = 'cnf'
-CNF_INCLUDE_DIR = '/etc/mysql/conf.d/'
+CNF_INCLUDE_DIR = '/etc/mysql/conf.d'
 CNF_MASTER = 'master-replication'
 CNF_SLAVE = 'slave-replication'
 
@@ -573,7 +573,7 @@ class BaseKeepAliveConnection(interfaces.PoolListener):
         # way than MySQL and PXC, which manifests itself as
         # an invalid packet sequence.  Handle it as well.
         except pymysql_err.InternalError as ex:
-            if "Packet sequence number wrong" in ex.message:
+            if "Packet sequence number wrong" in str(ex):
                 raise exc.DisconnectionError()
             else:
                 raise
@@ -641,7 +641,7 @@ class BaseMySqlApp(object):
             {MySQLConfParser.SERVER_CONF_SECTION: {'datadir': value}})
 
     @classmethod
-    def get_client_auth_file(self):
+    def get_client_auth_file(cls):
         return guestagent_utils.build_file_path("~", ".my.cnf")
 
     def __init__(self, status, local_sql_client, keep_alive_connection_cls):
@@ -764,9 +764,8 @@ class BaseMySqlApp(object):
                 pass
 
     def _create_mysql_confd_dir(self):
-        conf_dir = "/etc/mysql/conf.d"
-        LOG.debug("Creating %s.", conf_dir)
-        operating_system.create_directory(conf_dir, as_root=True)
+        LOG.debug("Creating %s.", CNF_INCLUDE_DIR)
+        operating_system.create_directory(CNF_INCLUDE_DIR, as_root=True)
 
     def _enable_mysql_on_boot(self):
         LOG.debug("Enabling MySQL on boot.")
@@ -934,7 +933,7 @@ class BaseMySqlApp(object):
         LOG.info("Starting slave replication.")
         with self.local_sql_client(self.get_engine()) as client:
             client.execute('START SLAVE')
-            self._wait_for_slave_status("ON", client, 60)
+            self._wait_for_slave_status("ON", client, 180)
 
     def stop_slave(self, for_failover):
         replication_user = None
@@ -944,7 +943,7 @@ class BaseMySqlApp(object):
             replication_user = result.first()['Master_User']
             client.execute('STOP SLAVE')
             client.execute('RESET SLAVE ALL')
-            self._wait_for_slave_status("OFF", client, 30)
+            self._wait_for_slave_status("OFF", client, 180)
             if not for_failover:
                 client.execute('DROP USER ' + replication_user)
         return {
