@@ -83,8 +83,9 @@ class MySQLRestoreMixin(object):
         if not os.path.exists(run_dir):
             utils.execute("mkdir", run_dir,
                           run_as_root=True, root_helper="sudo")
-            utils.execute("chown", "mysql:mysql", run_dir, err_log_file.name,
-                          run_as_root=True, root_helper="sudo")
+        utils.execute("chown", "mysql:mysql", run_dir, err_log_file.name,
+                      init_file.name, run_as_root=True, root_helper="sudo")
+
         child = pexpect.spawn(
             "sudo mysqld_safe --init-file=%s --log-error=%s" %
             (init_file.name, err_log_file.name))
@@ -135,24 +136,26 @@ class MySQLRestoreMixin(object):
         for initial datastore configuration.
         """
 
-        with tempfile.NamedTemporaryFile(mode='w') as init_file:
+        try:
+            # Do not attempt to delete these files as the 'trove' user.
+            # The process writing into it may have assumed its ownership.
+            # Only owners can delete temporary files (restricted deletion).
+            init_file = tempfile.NamedTemporaryFile(mode='w', delete=False)
             operating_system.write_file(init_file.name,
                                         self.RESET_ROOT_MYSQL_COMMANDS)
             operating_system.chmod(init_file.name, FileMode.ADD_READ_ALL,
                                    as_root=True)
-            # Do not attempt to delete the file as the 'trove' user.
-            # The process writing into it may have assumed its ownership.
-            # Only owners can delete temporary
-            # files (restricted deletion).
             err_log_file = tempfile.NamedTemporaryFile(
                 suffix=self._ERROR_LOG_SUFFIX,
                 delete=False)
-            try:
-                self._start_mysqld_safe_with_init_file(init_file, err_log_file)
-            finally:
-                err_log_file.close()
-                operating_system.remove(
-                    err_log_file.name, force=True, as_root=True)
+            self._start_mysqld_safe_with_init_file(init_file, err_log_file)
+        finally:
+            init_file.close()
+            err_log_file.close()
+            operating_system.remove(
+                init_file.name, force=True, as_root=True)
+            operating_system.remove(
+                err_log_file.name, force=True, as_root=True)
 
     def _find_first_error_message(self, fp):
         if self._is_non_zero_file(fp):
@@ -180,7 +183,8 @@ class MySQLDump(base.RestoreRunner, MySQLRestoreMixin):
 class InnoBackupEx(base.RestoreRunner, MySQLRestoreMixin):
     """Implementation of Restore Strategy for InnoBackupEx."""
     __strategy_name__ = 'innobackupex'
-    base_restore_cmd = 'sudo xbstream -x -C %(restore_location)s'
+    base_restore_cmd = ('sudo xbstream -x -C %(restore_location)s'
+                        ' 2>/tmp/xbstream_extract.log')
     base_prepare_cmd = ('sudo innobackupex'
                         ' --defaults-file=%(restore_location)s/backup-my.cnf'
                         ' --ibbackup=xtrabackup'
@@ -229,6 +233,43 @@ class InnoBackupEx(base.RestoreRunner, MySQLRestoreMixin):
         for f in files:
             os.unlink(f)
 
+    def check_process(self):
+        """Check whether xbstream restore is successful."""
+        # We first check the restore process exits with 0, however
+        # xbstream has a bug for creating new files:
+        # https://jira.percona.com/browse/PXB-1542
+        # So we also check the stderr with ignorance of some known
+        # non-error log lines. Currently we only need to ignore:
+        # "encryption: using gcrypt x.x.x"
+        # After PXB-1542 is fixed, we could just check the exit status.
+        LOG.debug('Checking return code of xbstream restore process.')
+        return_code = self.process.wait()
+        if return_code != 0:
+            LOG.erro('xbstream exited with %s', return_code)
+            return False
+
+        LOG.debug('Checking xbstream restore process stderr output.')
+        IGNORE_LINES = [
+            'encryption: using gcrypt ',
+        ]
+        with open('/tmp/xbstream_extract.log', 'r') as xbstream_log:
+            for line in xbstream_log:
+                # Ignore empty lines
+                if not line.strip():
+                    continue
+
+                # Ignore known non-error log lines
+                check_ignorance = [line.startswith(non_err)
+                                   for non_err in IGNORE_LINES]
+                if any(check_ignorance):
+                    continue
+                else:
+                    LOG.error('xbstream restore failed with: %s',
+                              line.rstrip('\n'))
+                    return False
+
+        return True
+
 
 class InnoBackupExIncremental(InnoBackupEx):
     __strategy_name__ = 'innobackupexincremental'
