@@ -32,10 +32,12 @@ from trove.common import exception
 from trove.common.glance_remote import create_glance_client
 from trove.common.i18n import _
 import trove.common.instance as tr_instance
+from trove.common import neutron
 from trove.common.notification import StartNotification
 from trove.common.remote import create_cinder_client
 from trove.common.remote import create_dns_client
 from trove.common.remote import create_guest_client
+from trove.common.remote import create_neutron_client
 from trove.common.remote import create_nova_client
 from trove.common import server_group as srv_grp
 from trove.common import template
@@ -225,15 +227,23 @@ class SimpleInstance(object):
         """Returns IPs that will be visible to the user."""
         if self.addresses is None:
             return None
+
         IPs = []
+        mgmt_networks = neutron.get_management_networks(self.context)
+
         for label in self.addresses:
-            if (re.search(CONF.network_label_regex, label) and
-                    len(self.addresses[label]) > 0):
-                IPs.extend([addr.get('addr')
-                            for addr in self.addresses[label]])
+            if label in mgmt_networks:
+                continue
+            if (CONF.network_label_regex and
+                    not re.search(CONF.network_label_regex, label)):
+                continue
+
+            IPs.extend([addr.get('addr') for addr in self.addresses[label]])
+
         # Includes ip addresses that match the regexp pattern
         if CONF.ip_regex and CONF.black_list_regex:
             IPs = filter_ips(IPs, CONF.ip_regex, CONF.black_list_regex)
+
         return IPs
 
     @property
@@ -616,6 +626,7 @@ class BaseInstance(SimpleInstance):
         self._guest = None
         self._nova_client = None
         self._volume_client = None
+        self._neutron_client = None
         self._server_group = None
         self._server_group_loaded = False
 
@@ -709,6 +720,13 @@ class BaseInstance(SimpleInstance):
                 self.context, region_name=self.db_info.region_id)
         return self._volume_client
 
+    @property
+    def neutron_client(self):
+        if not self._neutron_client:
+            self._neutron_client = create_neutron_client(
+                self.context, region_name=self.db_info.region_id)
+        return self._neutron_client
+
     def reset_task_status(self):
         LOG.info("Resetting task status to NONE on instance %s.",
                  self.id)
@@ -839,7 +857,7 @@ class Instance(BuiltInstance):
             remote_ds_ver.image)
         if local_image.checksum != remote_image.checksum:
             raise exception.TroveError(
-                "Images for Datastore %(ds)s do not match"
+                "Images for Datastore %(ds)s do not match "
                 "between regions %(local)s and %(remote)s." %
                 {'ds': datastore.name, 'local': CONF.os_region_name,
                  'remote': region_name})
@@ -914,6 +932,8 @@ class Instance(BuiltInstance):
                 target_size = flavor.ephemeral  # ephemeral_Storage
 
         if backup_id:
+            Backup.verify_swift_auth_token(context)
+
             call_args['backup_id'] = backup_id
             backup_info = Backup.get_by_id(context, backup_id)
             if not backup_info.is_done_successfuly:
@@ -937,6 +957,8 @@ class Instance(BuiltInstance):
                     datastore2=datastore.name)
 
         if slave_of_id:
+            Backup.verify_swift_auth_token(context)
+
             if databases or users:
                 raise exception.ReplicaCreateWithUsersDatabasesError()
             call_args['replica_of'] = slave_of_id
@@ -1574,12 +1596,14 @@ class Instances(object):
 
 class DBInstance(dbmodels.DatabaseModelBase):
 
-    _data_fields = ['name', 'created', 'compute_instance_id',
-                    'task_id', 'task_description', 'task_start_time',
-                    'volume_id', 'deleted', 'tenant_id',
-                    'datastore_version_id', 'configuration_id', 'slave_of_id',
-                    'cluster_id', 'shard_id', 'type', 'region_id',
-                    'encrypted_key']
+    _data_fields = ['created', 'updated', 'name', 'hostname',
+                    'compute_instance_id', 'task_id', 'task_description',
+                    'task_start_time', 'volume_id', 'flavor_id',
+                    'volume_size', 'tenant_id', 'server_status',
+                    'deleted', 'deleted_at', 'datastore_version_id',
+                    'configuration_id', 'slave_of_id', 'cluster_id',
+                    'shard_id', 'type', 'region_id', 'encrypted_key']
+    _table_name = 'instances'
 
     def __init__(self, task_status, **kwargs):
         """
@@ -1763,6 +1787,7 @@ def save_instance_fault(instance_id, message, details, skip_delta=None):
 class DBInstanceFault(dbmodels.DatabaseModelBase):
     _data_fields = ['instance_id', 'message', 'details',
                     'created', 'updated', 'deleted', 'deleted_at']
+    _table_name = 'instance_faults'
 
     def __init__(self, **kwargs):
         super(DBInstanceFault, self).__init__(**kwargs)
@@ -1775,6 +1800,7 @@ class DBInstanceFault(dbmodels.DatabaseModelBase):
 class InstanceServiceStatus(dbmodels.DatabaseModelBase):
     _data_fields = ['instance_id', 'status_id', 'status_description',
                     'updated_at']
+    _table_name = 'service_statuses'
 
     def __init__(self, status, **kwargs):
         kwargs["status_id"] = status.code
@@ -1816,7 +1842,7 @@ class InstanceServiceStatus(dbmodels.DatabaseModelBase):
 
 def persisted_models():
     return {
-        'instance': DBInstance,
+        'instances': DBInstance,
         'instance_faults': DBInstanceFault,
         'service_statuses': InstanceServiceStatus,
     }
