@@ -21,6 +21,7 @@ from eventlet import greenthread
 from eventlet.timeout import Timeout
 from novaclient import exceptions as nova_exceptions
 from oslo_log import log as logging
+from oslo_utils import netutils
 from swiftclient.client import ClientException
 
 from trove.backup import models as bkup_models
@@ -483,29 +484,17 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
         files = self.get_injected_files(datastore_manager)
         cinder_volume_type = volume_type or CONF.cinder_volume_type
-        if CONF.use_nova_server_volume:
-            volume_info = self._create_server_volume(
-                flavor['id'],
-                image_id,
-                security_groups,
-                datastore_manager,
-                volume_size,
-                availability_zone,
-                nics,
-                files,
-                scheduler_hints)
-        else:
-            volume_info = self._create_server_volume_individually(
-                flavor['id'],
-                image_id,
-                security_groups,
-                datastore_manager,
-                volume_size,
-                availability_zone,
-                nics,
-                files,
-                cinder_volume_type,
-                scheduler_hints)
+        volume_info = self._create_server_volume(
+            flavor['id'],
+            image_id,
+            security_groups,
+            datastore_manager,
+            volume_size,
+            availability_zone,
+            nics,
+            files,
+            cinder_volume_type,
+            scheduler_hints)
 
         config = self._render_config(flavor)
 
@@ -636,6 +625,12 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 'replica': self.id
             }
             err = inst_models.InstanceTasks.BUILDING_ERROR_REPLICA
+            e_create_fault = create_log_fmt % create_fmt_content
+            e_create_stack = traceback.format_exc()
+            # we persist fault details to source instance
+            inst_models.save_instance_fault(slave_of_id, e_create_fault,
+                                            e_create_stack)
+
             # if the delete of the 'bad' backup fails, it'll mask the
             # create exception, so we trap it here
             try:
@@ -663,7 +658,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                                 create_fmt_content, err)
 
     def report_root_enabled(self):
-        mysql_models.RootHistory.create(self.context, self.id, 'root')
+        mysql_models.RootHistory.create(self.context, self.id)
 
     def update_statuses_on_time_out(self):
 
@@ -724,57 +719,12 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             except AttributeError:
                 pass
             server_message = "\nServer error: %s" % server_fault_message
-            raise TroveError(_("Server not active, status: %(status)s"
+            raise TroveError(_("Server not active, status: %(status)s "
                                "%(srv_msg)s") %
                              {'status': server_status,
                               'srv_msg': server_message})
         return False
 
-    def _create_server_volume(self, flavor_id, image_id, security_groups,
-                              datastore_manager, volume_size,
-                              availability_zone, nics, files,
-                              scheduler_hints):
-        LOG.debug("Begin _create_server_volume for id: %s", self.id)
-        try:
-            userdata = self._prepare_userdata(datastore_manager)
-            name = self.hostname or self.name
-            volume_desc = ("datastore volume for %s" % self.id)
-            volume_name = ("datastore-%s" % self.id)
-            volume_ref = {'size': volume_size, 'name': volume_name,
-                          'description': volume_desc}
-            config_drive = CONF.use_nova_server_config_drive
-            server = self.nova_client.servers.create(
-                name, image_id, flavor_id,
-                files=files, volume=volume_ref,
-                security_groups=security_groups,
-                availability_zone=availability_zone,
-                nics=nics, config_drive=config_drive,
-                userdata=userdata, scheduler_hints=scheduler_hints)
-            server_dict = server._info
-            LOG.debug("Created new compute instance %(server_id)s "
-                      "for id: %(id)s\nServer response: %(response)s",
-                      {'server_id': server.id, 'id': self.id,
-                       'response': server_dict})
-
-            volume_id = None
-            for volume in server_dict.get('os:volumes', []):
-                volume_id = volume.get('id')
-
-            # Record the server ID and volume ID in case something goes wrong.
-            self.update_db(compute_instance_id=server.id, volume_id=volume_id)
-        except Exception as e:
-            log_fmt = "Error creating server and volume for instance %s"
-            exc_fmt = _("Error creating server and volume for instance %s")
-            LOG.debug("End _create_server_volume for id: %s", self.id)
-            err = inst_models.InstanceTasks.BUILDING_ERROR_SERVER
-            self._log_and_raise(e, log_fmt, exc_fmt, self.id, err)
-
-        device_path = self.device_path
-        mount_point = CONF.get(datastore_manager).mount_point
-        volume_info = {'device_path': device_path, 'mount_point': mount_point}
-        LOG.debug("End _create_server_volume for id: %s", self.id)
-        return volume_info
-
     def _build_sg_rules_mapping(self, rule_ports):
         final = []
         cidr = CONF.trove_security_group_rule_cidr
@@ -785,22 +735,21 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                           'to_': str(to_)})
         return final
 
-    def _create_server_volume_individually(self, flavor_id, image_id,
-                                           security_groups, datastore_manager,
-                                           volume_size, availability_zone,
-                                           nics, files, volume_type,
-                                           scheduler_hints):
-        LOG.debug("Begin _create_server_volume_individually for id: %s",
-                  self.id)
+    def _create_server_volume(self, flavor_id, image_id,
+                              security_groups, datastore_manager,
+                              volume_size, availability_zone,
+                              nics, files, volume_type,
+                              scheduler_hints):
+        LOG.debug("Begin _create_server_volume for id: %s", self.id)
         server = None
         volume_info = self._build_volume_info(datastore_manager,
                                               volume_size=volume_size,
                                               volume_type=volume_type)
-        block_device_mapping = volume_info['block_device']
+        block_device_mapping_v2 = volume_info['block_device']
         try:
             server = self._create_server(flavor_id, image_id, security_groups,
                                          datastore_manager,
-                                         block_device_mapping,
+                                         block_device_mapping_v2,
                                          availability_zone, nics, files,
                                          scheduler_hints)
             server_id = server.id
@@ -811,8 +760,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             exc_fmt = _("Failed to create server for instance %s")
             err = inst_models.InstanceTasks.BUILDING_ERROR_SERVER
             self._log_and_raise(e, log_fmt, exc_fmt, self.id, err)
-        LOG.debug("End _create_server_volume_individually for id: %s",
-                  self.id)
+        LOG.debug("End _create_server_volume for id: %s", self.id)
         return volume_info
 
     def _build_volume_info(self, datastore_manager, volume_size=None,
@@ -842,7 +790,6 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 'block_device': None,
                 'device_path': device_path,
                 'mount_point': mount_point,
-                'volumes': None,
             }
         return volume_info
 
@@ -887,12 +834,25 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
     def _build_volume(self, v_ref, datastore_manager):
         LOG.debug("Created volume %s", v_ref)
-        # The mapping is in the format:
-        # <id>:[<type>]:[<size(GB)>]:[<delete_on_terminate>]
-        # setting the delete_on_terminate instance to true=1
-        mapping = "%s:%s:%s:%s" % (v_ref.id, '', v_ref.size, 1)
+        # TODO(zhaochao): from Liberty, Nova libvirt driver does not honor
+        # user-supplied device name anymore, so we may need find a new
+        # method to make sure the volume is correctly mounted inside the
+        # guest, please refer to the 'intermezzo-problem-with-device-names'
+        # section of Nova user referrence at:
+        # https://docs.openstack.org/nova/latest/user/block-device-mapping.html
         bdm = CONF.block_device_mapping
-        block_device = {bdm: mapping}
+
+        # use Nova block_device_mapping_v2, referrence:
+        # https://developer.openstack.org/api-ref/compute/#create-server
+        # setting the delete_on_terminate instance to true=1
+        block_device_v2 = [{
+            "uuid": v_ref.id,
+            "source_type": "volume",
+            "destination_type": "volume",
+            "device_name": bdm,
+            "volume_size": v_ref.size,
+            "delete_on_termination": True
+        }]
         created_volumes = [{'id': v_ref.id,
                             'size': v_ref.size}]
 
@@ -903,15 +863,14 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                   "volume = %(volume)s\n"
                   "device_path = %(path)s\n"
                   "mount_point = %(point)s",
-                  {"device": block_device,
+                  {"device": block_device_v2,
                    "volume": created_volumes,
                    "path": device_path,
                    "point": mount_point})
 
-        volume_info = {'block_device': block_device,
+        volume_info = {'block_device': block_device_v2,
                        'device_path': device_path,
-                       'mount_point': mount_point,
-                       'volumes': created_volumes}
+                       'mount_point': mount_point}
         return volume_info
 
     def _prepare_userdata(self, datastore_manager):
@@ -924,17 +883,17 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         return userdata
 
     def _create_server(self, flavor_id, image_id, security_groups,
-                       datastore_manager, block_device_mapping,
+                       datastore_manager, block_device_mapping_v2,
                        availability_zone, nics, files={},
                        scheduler_hints=None):
         userdata = self._prepare_userdata(datastore_manager)
         name = self.hostname or self.name
-        bdmap = block_device_mapping
+        bdmap_v2 = block_device_mapping_v2
         config_drive = CONF.use_nova_server_config_drive
 
         server = self.nova_client.servers.create(
             name, image_id, flavor_id, files=files, userdata=userdata,
-            security_groups=security_groups, block_device_mapping=bdmap,
+            security_groups=security_groups, block_device_mapping_v2=bdmap_v2,
             availability_zone=availability_zone, nics=nics,
             config_drive=config_drive, scheduler_hints=scheduler_hints)
         LOG.debug("Created new compute instance %(server_id)s "
@@ -1218,31 +1177,46 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
     def _get_floating_ips(self):
         """Returns floating ips as a dict indexed by the ip."""
         floating_ips = {}
-        neutron_client = remote.create_neutron_client(self.context)
-        network_floating_ips = neutron_client.list_floatingips()
+        network_floating_ips = self.neutron_client.list_floatingips()
         for ip in network_floating_ips.get('floatingips'):
-            floating_ips.update({ip.get('floating_ip_address'): ip})
+            floating_ips.update(
+                {ip.get('floating_ip_address'): ip.get('id')})
         LOG.debug("In _get_floating_ips(), returning %s", floating_ips)
         return floating_ips
 
     def detach_public_ips(self):
         LOG.debug("Begin detach_public_ips for instance %s", self.id)
         removed_ips = []
-        server_id = self.db_info.compute_instance_id
-        nova_instance = self.nova_client.servers.get(server_id)
         floating_ips = self._get_floating_ips()
         for ip in self.get_visible_ip_addresses():
             if ip in floating_ips:
-                nova_instance.remove_floating_ip(ip)
-                removed_ips.append(ip)
+                fip_id = floating_ips[ip]
+                self.neutron_client.update_floatingip(
+                    fip_id, {'floatingip': {'port_id': None}})
+                removed_ips.append(fip_id)
         return removed_ips
 
     def attach_public_ips(self, ips):
         LOG.debug("Begin attach_public_ips for instance %s", self.id)
         server_id = self.db_info.compute_instance_id
-        nova_instance = self.nova_client.servers.get(server_id)
-        for ip in ips:
-            nova_instance.add_floating_ip(ip)
+
+        # NOTE(zhaochao): in Nova's addFloatingIp, the new floating ip will
+        # always be associated with the first IPv4 fixed address of the Nova
+        # instance, we're doing the same thing here, after add_floating_ip is
+        # removed from novaclient.
+        server_ports = (self.neutron_client.list_ports(device_id=server_id)
+                        .get('ports'))
+        fixed_address, port_id = next(
+            (fixed_ip['ip_address'], port['id'])
+            for port in server_ports
+            for fixed_ip in port.get('fixed_ips')
+            if netutils.is_valid_ipv4(fixed_ip['ip_address']))
+
+        for fip_id in ips:
+            self.neutron_client.update_floatingip(
+                fip_id, {'floatingip': {
+                    'port_id': port_id,
+                    'fixed_ip_address': fixed_address}})
 
     def enable_as_master(self):
         LOG.debug("Calling enable_as_master on %s", self.id)
@@ -1389,6 +1363,8 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 volume = self.volume_client.volumes.get(self.volume_id)
                 volume_device = self._fix_device_path(
                     volume.attachments[0]['device'])
+                if volume:
+                    upgrade_info['device'] = volume_device
 
             # BUG(1650518): Cleanup in the Pike release some instances
             # that we will be upgrading will be pre secureserialier
@@ -1421,11 +1397,8 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
             if not self.server_status_matches(['ACTIVE']):
                 raise TroveError(_("Instance %(instance)s failed to "
                                    "upgrade to %(datastore_version)s"),
-                                 {'instance': self,
-                                  'datastore_version': datastore_version})
-
-            if volume:
-                upgrade_info['device'] = volume_device
+                                 instance=self,
+                                 datastore_version=datastore_version)
 
             self.guest.post_upgrade(upgrade_info)
 
