@@ -53,7 +53,7 @@ def _get_user_count(server_info):
            ' where user like \\\"slave_%\\\"\\\'')
     server = create_server_connection(server_info.id)
     stdout, stderr = server.execute(cmd)
-    return int(stdout.rstrip())
+    return int(stdout)
 
 
 def slave_is_running(running=True):
@@ -177,7 +177,7 @@ class VerifySlave(object):
         return find_database
 
     @test
-    @time_out(5 * 60)
+    @time_out(20 * 60)
     def test_correctly_started_replication(self):
         poll_until(slave_is_running())
 
@@ -364,10 +364,7 @@ class DetachReplica(object):
             cmd = "mysql -BNq -e \\\'select @@read_only\\\'"
             server = create_server_connection(slave_instance.id)
             stdout, stderr = server.execute(cmd)
-            if (stdout.rstrip() != "0"):
-                return False
-            else:
-                return True
+            return stdout.rstrip() == "0"
         poll_until(check_not_read_only)
 
 
