@@ -19,6 +19,7 @@ from cinderclient import exceptions as cinder_exceptions
 import cinderclient.v2.client as cinderclient
 from cinderclient.v2 import volumes as cinderclient_volumes
 from mock import Mock, MagicMock, patch, PropertyMock, call
+import neutronclient.v2_0.client as neutronclient
 from novaclient import exceptions as nova_exceptions
 import novaclient.v2.flavors
 import novaclient.v2.servers
@@ -59,11 +60,6 @@ INST_ID = 'dbinst-id-1'
 VOLUME_ID = 'volume-id-1'
 
 
-class _fake_neutron_client(object):
-    def list_floatingips(self):
-        return {'floatingips': [{'floating_ip_address': '192.168.10.1'}]}
-
-
 class FakeOptGroup(object):
     def __init__(self, tcp_ports=['3306', '3301-3307'],
                  udp_ports=[], icmp=False):
@@ -81,13 +77,14 @@ class fake_Server(object):
         self.files = None
         self.userdata = None
         self.security_groups = None
-        self.block_device_mapping = None
+        self.block_device_mapping_v2 = None
         self.status = 'ACTIVE'
 
 
 class fake_ServerManager(object):
     def create(self, name, image_id, flavor_id, files, userdata,
-               security_groups, block_device_mapping, availability_zone=None,
+               security_groups, block_device_mapping_v2=None,
+               availability_zone=None,
                nics=None, config_drive=False,
                scheduler_hints=None):
         server = fake_Server()
@@ -98,7 +95,7 @@ class fake_ServerManager(object):
         server.files = files
         server.userdata = userdata
         server.security_groups = security_groups
-        server.block_device_mapping = block_device_mapping
+        server.block_device_mapping_v2 = block_device_mapping_v2
         server.availability_zone = availability_zone
         server.nics = nics
         return server
@@ -297,6 +294,25 @@ class FreshInstanceTasksTest(BaseFreshInstanceTasksTest):
         # verify
         self.assertIsNotNone(server)
 
+    @patch.object(taskmanager_models.FreshInstanceTasks, 'hostname',
+                  new_callable=PropertyMock,
+                  return_value='fake-hostname')
+    def test_servers_create_block_device_mapping_v2(self, mock_hostname):
+        mock_nova_client = self.freshinstancetasks.nova_client = Mock()
+        mock_servers_create = mock_nova_client.servers.create
+        self.freshinstancetasks._create_server('fake-flavor', 'fake-image',
+                                               None, 'mysql', None, None,
+                                               None)
+        mock_servers_create.assert_called_with('fake-hostname', 'fake-image',
+                                               'fake-flavor', files={},
+                                               userdata=None,
+                                               security_groups=None,
+                                               block_device_mapping_v2=None,
+                                               availability_zone=None,
+                                               nics=None,
+                                               config_drive=True,
+                                               scheduler_hints=None)
+
     @patch.object(InstanceServiceStatus, 'find_by',
                   return_value=fake_InstanceServiceStatus.find_by())
     @patch.object(DBInstance, 'find_by',
@@ -375,6 +391,62 @@ class FreshInstanceTasksTest(BaseFreshInstanceTasksTest):
             'mysql', mock_build_volume_info()['block_device'], None,
             None, mock_get_injected_files(), {'group': 'sg-id'})
 
+    @patch.object(BaseInstance, 'update_db')
+    @patch.object(taskmanager_models, 'create_cinder_client')
+    @patch.object(taskmanager_models.FreshInstanceTasks, 'device_path',
+                  new_callable=PropertyMock,
+                  return_value='fake-device-path')
+    @patch.object(taskmanager_models.FreshInstanceTasks, 'volume_support',
+                  new_callable=PropertyMock,
+                  return_value=True)
+    def test_build_volume_info(self, mock_volume_support, mock_device_path,
+                               mock_create_cinderclient, mock_update_db):
+        cfg.CONF.set_override('block_device_mapping', 'fake-bdm')
+        cfg.CONF.set_override('mount_point', 'fake-mount-point',
+                              group='mysql')
+        mock_cinderclient = mock_create_cinderclient.return_value
+        mock_volume = Mock(name='fake-vol', id='fake-vol-id',
+                           size=2, status='available')
+        mock_cinderclient.volumes.create.return_value = mock_volume
+        mock_cinderclient.volumes.get.return_value = mock_volume
+        volume_info = self.freshinstancetasks._build_volume_info(
+            'mysql', volume_size=2, volume_type='volume_type')
+        expected = {
+            'block_device': [{
+                'uuid': 'fake-vol-id',
+                'source_type': 'volume',
+                'destination_type': 'volume',
+                'device_name': 'fake-bdm',
+                'volume_size': 2,
+                'delete_on_termination': True}],
+            'device_path': 'fake-device-path',
+            'mount_point': 'fake-mount-point'
+        }
+        self.assertEqual(expected, volume_info)
+
+    @patch.object(BaseInstance, 'update_db')
+    @patch.object(taskmanager_models.FreshInstanceTasks, '_create_volume')
+    @patch.object(taskmanager_models.FreshInstanceTasks, 'device_path',
+                  new_callable=PropertyMock,
+                  return_value='fake-device-path')
+    @patch.object(taskmanager_models.FreshInstanceTasks, 'volume_support',
+                  new_callable=PropertyMock,
+                  return_value=False)
+    def test_build_volume_info_without_volume(self, mock_volume_support,
+                                              mock_device_path,
+                                              mock_create_volume,
+                                              mock_update_db):
+        cfg.CONF.set_override('mount_point', 'fake-mount-point',
+                              group='mysql')
+        volume_info = self.freshinstancetasks._build_volume_info('mysql')
+        self.assertFalse(mock_create_volume.called)
+        expected = {
+            'block_device': None,
+            'device_path': 'fake-device-path',
+            'mount_point': 'fake-mount-point'
+        }
+        self.assertEqual(expected, volume_info)
+
     @patch.object(trove.guestagent.api.API, 'attach_replication_slave')
     @patch.object(rpc, 'get_client')
     @patch.object(DBInstance, 'get_by')
@@ -617,6 +689,19 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
         stub_volume_mgr.get = MagicMock(return_value=stub_new_volume)
         stub_volume_mgr.attach = MagicMock(return_value=None)
 
+    def _stub_neutron_client(self):
+        stub_neutron_client = self.instance_task._neutron_client = MagicMock(
+            spec=neutronclient.Client)
+        stub_neutron_client.list_floatingips = MagicMock(
+            return_value={'floatingips': [{
+                'floating_ip_address': '192.168.10.1',
+                'id': 'fake-floatingip-id'}]})
+        stub_neutron_client.list_ports = MagicMock(
+            return_value={'ports': [{
+                'fixed_ips': [{'ip_address': '10.0.0.1'},
+                              {'ip_address': 'fd4a:7bef:d1ed:1::1'}],
+                'id': 'fake-port-id'}]})
+
     def setUp(self):
         super(BuiltInstanceTasksTest, self).setUp()
         self.new_flavor = {'id': 8, 'ram': 768, 'name': 'bigger_flavor'}
@@ -726,6 +811,10 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
         if 'volume' in self._testMethodName:
             self._stub_volume_client()
 
+        if ('floating_ips' in self._testMethodName or
+                'public_ips' in self._testMethodName):
+            self._stub_neutron_client()
+
     def tearDown(self):
         super(BuiltInstanceTasksTest, self).tearDown()
 
@@ -856,25 +945,32 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
                               Mock())
 
     def test_get_floating_ips(self):
-        with patch.object(remote, 'create_neutron_client',
-                          return_value=_fake_neutron_client()):
-            floating_ips = self.instance_task._get_floating_ips()
-            self.assertEqual('192.168.10.1',
-                             floating_ips['192.168.10.1'].get(
-                                 'floating_ip_address'))
+        floating_ips = self.instance_task._get_floating_ips()
+        self.assertEqual({'192.168.10.1': 'fake-floatingip-id'},
+                         floating_ips)
 
     @patch.object(BaseInstance, 'get_visible_ip_addresses',
                   return_value=['192.168.10.1'])
     def test_detach_public_ips(self, mock_address):
-        with patch.object(remote, 'create_neutron_client',
-                          return_value=_fake_neutron_client()):
-            removed_ips = self.instance_task.detach_public_ips()
-            self.assertEqual(['192.168.10.1'], removed_ips)
+        removed_ips = self.instance_task.detach_public_ips()
+        self.assertEqual(['fake-floatingip-id'], removed_ips)
+        mock_update_floatingip = (self.instance_task.neutron_client
+                                  .update_floatingip)
+        mock_update_floatingip.assert_called_once_with(
+            removed_ips[0], {'floatingip': {'port_id': None}})
 
     def test_attach_public_ips(self):
-        self.instance_task.attach_public_ips(['192.168.10.1'])
-        self.stub_verifying_server.add_floating_ip.assert_called_with(
-            '192.168.10.1')
+        self.instance_task.attach_public_ips(['fake-floatingip-id'])
+        mock_list_ports = (self.instance_task.neutron_client
+                           .list_ports)
+        mock_list_ports.assert_called_once_with(device_id='computeinst-id-1')
+
+        mock_update_floatingip = (self.instance_task.neutron_client
+                                  .update_floatingip)
+        mock_update_floatingip.assert_called_once_with(
+            'fake-floatingip-id',
+            {'floatingip': {'port_id': 'fake-port-id',
+                            'fixed_ip_address': '10.0.0.1'}})
 
     @patch.object(BaseInstance, 'update_db')
     def test_enable_as_master(self, mock_update_db):
@@ -1084,17 +1180,20 @@ class RootReportTest(trove_testtools.TestCase):
         super(RootReportTest, self).tearDown()
 
     def test_report_root_first_time(self):
+        context = Mock()
+        context.user = utils.generate_uuid()
         report = mysql_models.RootHistory.create(
-            None, utils.generate_uuid(), 'root')
+            context, utils.generate_uuid())
         self.assertIsNotNone(report)
 
     def test_report_root_double_create(self):
+        context = Mock()
+        context.user = utils.generate_uuid()
         uuid = utils.generate_uuid()
-        history = mysql_models.RootHistory(uuid, 'root').save()
+        history = mysql_models.RootHistory(uuid, context.user).save()
         with patch.object(mysql_models.RootHistory, 'load',
                           Mock(return_value=history)):
-            report = mysql_models.RootHistory.create(
-                None, uuid, 'root')
+            report = mysql_models.RootHistory.create(context, uuid)
             self.assertTrue(mysql_models.RootHistory.load.called)
             self.assertEqual(history.user, report.user)
             self.assertEqual(history.id, report.id)
@@ -1106,17 +1205,17 @@ class ClusterRootTest(trove_testtools.TestCase):
     @patch.object(common_models.Root, "create")
     def test_cluster_root_create(self, root_create, root_history_create):
         context = Mock()
+        context.user = utils.generate_uuid()
         uuid = utils.generate_uuid()
-        user = "root"
         password = "rootpassword"
         cluster_instances = [utils.generate_uuid(), utils.generate_uuid()]
-        common_models.ClusterRoot.create(context, uuid, user, password,
+        common_models.ClusterRoot.create(context, uuid, password,
                                          cluster_instances)
-        root_create.assert_called_with(context, uuid, user, password,
+        root_create.assert_called_with(context, uuid, password,
                                        cluster_instances_list=None)
         self.assertEqual(2, root_history_create.call_count)
         calls = [
-            call(context, cluster_instances[0], user),
-            call(context, cluster_instances[1], user)
+            call(context, cluster_instances[0]),
+            call(context, cluster_instances[1])
         ]
         root_history_create.assert_has_calls(calls)
